@@ -212,9 +212,9 @@ If the country has no sub countries, returns undef.
 
 =head1 SEE ALSO
 
-All codes have been downloaded from the latest version of the Alioth project
-L<https://pkg-isocodes.alioth.debian.org/>
-
+All codes have been downloaded from the latest version of the Debian Salsa project
+L<https://salsa.debian.org/iso-codes-team/iso-codes/>
+and then files iso_3166-1.json, iso_3166-2.json
 
 L<Locale::Country>,L<Lingua::EN::AddressParse>,
 L<Geo::StreetAddress::US>,L<Geo::PostalAddress>,L<Geo::IP>
@@ -227,10 +227,6 @@ ISO 3166-2 Codes for the representation of names of countries and their
 subdivisions - Part 2: Country subdivision code
 
 
-L<http://www.statoids.com/statoids.html> is a good source for sub country codes plus
-other statistical data.
-
-
 =head1 LIMITATIONS
 
 The ISO 3166-2 standard romanizes the names of provinces and regions in non-latin
@@ -270,15 +266,13 @@ This library is free software; you can redistribute it and/or modify it under th
 
 Ron Savage for many corrections to the data
 
-
 Terrence Brannon produced Locale::US, which was the starting point for
 this module.
 
 
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2018 Kim Ryan. All rights reserved.
+Copyright (c) 2019 Kim Ryan. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -298,7 +292,7 @@ use Locale::SubCountry::Codes;
 #-------------------------------------------------------------------------------
 
 
-our $VERSION = '2.03';
+our $VERSION = '2.07';
 
 # Define all the methods for the 'world' class here. Note that because the
 # name space inherits from the Locale::SubCountry name space, the
@@ -354,7 +348,7 @@ sub all_codes
 #-------------------------------------------------------------------------------
 
 package Locale::SubCountry;
-our $VERSION = '2.03';
+our $VERSION = '2.07';
 
 #-------------------------------------------------------------------------------
 # Initialization code which will be run first to create global data structure.
